@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -1342,6 +1342,34 @@ class RedisClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def KillMasterGroup(self, request):
+        """模拟故障
+
+        :param request: Request instance for KillMasterGroup.
+        :type request: :class:`tencentcloud.redis.v20180412.models.KillMasterGroupRequest`
+        :rtype: :class:`tencentcloud.redis.v20180412.models.KillMasterGroupResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("KillMasterGroup", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.KillMasterGroupResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ManualBackupInstance(self, request):
         """手动备份Redis实例
 
